#ifndef _ELM_SCROLLER_INTERNAL_PART_EO_H_
#define _ELM_SCROLLER_INTERNAL_PART_EO_H_

#ifndef _ELM_SCROLLER_INTERNAL_PART_EO_CLASS_TYPE
#define _ELM_SCROLLER_INTERNAL_PART_EO_CLASS_TYPE

typedef Eo Elm_Scroller_Internal_Part;

#endif

#ifndef _ELM_SCROLLER_INTERNAL_PART_EO_TYPES
#define _ELM_SCROLLER_INTERNAL_PART_EO_TYPES


#endif
/** Elementary scroller internal part class
 *
 * @ingroup Elm_Scroller_Internal_Part
 */
#define ELM_SCROLLER_INTERNAL_PART_CLASS elm_scroller_internal_part_class_get()

EWAPI const Efl_Class *elm_scroller_internal_part_class_get(void);

#endif
